spannertools.Spanner
====================

.. abjad-lineage:: abjad.tools.spannertools.Spanner.Spanner.Spanner

.. autoclass:: abjad.tools.spannertools.Spanner.Spanner.Spanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.append
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.append_left
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.attach
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.components
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.detach
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.extend
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.extend_left
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.fracture
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.fuse
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.get_duration
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.get_timespan
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.index
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.leaves
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.override
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.pop
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.pop_left
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.set
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__call__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__contains__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__copy__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__eq__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__getitem__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__len__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__lt__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__ne__
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.set
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__repr__
   :noindex:
